@@ -49,11 +49,11 @@ def test_cli_add_client(mock_app, database, test_client):
         [
             "add",
             "client",
-            "-id",
+            "--id",
             test_client["_id"],
-            "-token",
+            "--token",
             test_client["auth_token"],
-            "-url",
+            "--url",
             test_client["base_url"],
         ],
     )
@@ -70,11 +70,11 @@ def test_cli_add_client(mock_app, database, test_client):
         [
             "add",
             "client",
-            "-id",
+            "--id",
             test_client["_id"],
-            "-token",
+            "--token",
             test_client["auth_token"],
-            "-url",
+            "--url",
             test_client["base_url"],
         ],
     )
@@ -97,15 +97,15 @@ def test_cli_add_node(mock_app, database, test_node):
         [
             "add",
             "node",
-            "-id",
+            "--id",
             test_node["_id"],
-            "-label",
+            "--label",
             "This is a test node",
-            "-token",
+            "--token",
             test_node["auth_token"],
-            "-matching_url",
+            "--matching_url",
             test_node["matching_url"],
-            "-accepted_content",
+            "--accepted_content",
             test_node["accepted_content"],
         ],
     )
@@ -121,15 +121,15 @@ def test_cli_add_node(mock_app, database, test_node):
         [
             "add",
             "node",
-            "-id",
+            "--id",
             test_node["_id"],
-            "-label",
+            "--label",
             "This is a test node",
-            "-token",
+            "--token",
             test_node["auth_token"],
-            "-matching_url",
+            "--matching_url",
             test_node["matching_url"],
-            "-accepted_content",
+            "--accepted_content",
             test_node["accepted_content"],
         ],
     )
